@@ -1,7 +1,7 @@
 import numpy as np
 from . import Linear
 from typing import Tuple
-from .utilities import MatMul, MatInv, MatDiag, getOrder, MatRemoveDim
+from nptyping import NDArray
 
 class Polynomial(Linear):
     """
@@ -32,19 +32,19 @@ class Polynomial(Linear):
         self._Order = value
 
     @property
-    def Beta(self):
+    def Beta(self) -> NDArray:
         return super(Polynomial, self).Beta[...,0]
 
     @property
-    def BetaFitError(self):
+    def BetaFitError(self) -> NDArray:
         return super(Polynomial, self).BetaFitError[...,0]
 
-    def __init__(self, x:np.ndarray, y:np.ndarray, order:int, fitDim:int=0, confidenceInterval:float=0.95, simult:bool=False,  rescale:bool=False):
+    def __init__(self, x:NDArray, y:NDArray, order:int, fitDim:int=0, confidenceInterval:float=0.95, simult:bool=False,  rescale:bool=False):
         self._initialized=False
         self.Order = order
         super(Polynomial, self).__init__(self._polify(x), y.reshape(y.shape + (1,)), fitDim, confidenceInterval, simult, x.ndim, rescale)
 
-    def _polify(self, x:np.ndarray):
+    def _polify(self, x:NDArray) -> NDArray:
         """
         Makes a vandermonde matrix of the right polynomial order
         using the provided array. The required dimension will be appended
@@ -58,13 +58,13 @@ class Polynomial(Linear):
 
         return out
 
-    def Eval(self, x:np.ndarray):
+    def Eval(self, x:NDArray) -> NDArray:
         return super(Polynomial, self).Eval(self._polify(x))[...,0]
 
-    def EvalFitError(self, x:np.ndarray):
+    def EvalFitError(self, x:NDArray) -> NDArray:
         return super(Polynomial, self).EvalFitError(self._polify(x))[...,0]
 
-    def EvalPredictionError(self, x:np.ndarray):
+    def EvalPredictionError(self, x:NDArray) -> NDArray:
         return super(Polynomial, self).EvalPredictionError(self._polify(x))[...,0]
 
     def _computeFitStats(self):
