@@ -120,7 +120,7 @@ def MatRemoveDim(A:NDArray, axis=int) -> NDArray:
     order = [x for x in range(A.ndim) if x != axis] + [axis]
     return A.transpose(order)[...,0]
 
-def FFTGuess(x:NDArray, y:NDArray, axis=-1) -> Tuple[float, float, float, float]:
+def FFTGuess(x:NDArray, y:NDArray, axis:int=-1, warningEnabled:bool=True) -> Tuple[float, float, float, float]:
     """
     Guesses the parameters used for a CosineFit using the Fourier transform. 
     This approach can be limited if more than one frequency is prominent, 
@@ -173,7 +173,7 @@ def FFTGuess(x:NDArray, y:NDArray, axis=-1) -> Tuple[float, float, float, float]
     totalEnergy = np.sum(A[1:]**2) # without counting the DC offset
     peakEnergy = amp**2
 
-    if peakEnergy/totalEnergy < 0.5:
+    if warningEnabled and (peakEnergy/totalEnergy < 0.5):
         print("Warning: the most prominent peak does not account for more than half the energy, the FFTGuess may not be the best one. ")
 
     return amp, omega, phi, voff
